/* Totem Mozilla plugin
 *
 * Copyright (C) <2005> Bastien Nocera <hadess@hadess.net>
 *
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Library General Public
 * License as published by the Free Software Foundation; either
 * version 2 of the License, or (at your option) any later version.
 *
 * This library is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 * Library General Public License for more details.
 *
 * You should have received a copy of the GNU Library General Public
 * License along with this library; if not, write to the
 * Free Software Foundation, Inc., 59 Temple Place - Suite 330,
 * Boston, MA 02111-1307, USA.
 */

#define TOTEM_OPTION_XID		"xid"
#define TOTEM_OPTION_WIDTH		"width"
#define TOTEM_OPTION_HEIGHT		"height"
#define TOTEM_OPTION_URL		"url"
#define TOTEM_OPTION_CONTROLS_HIDDEN	"nocontrols"
#define TOTEM_OPTION_HREF		"href"
#define TOTEM_OPTION_TARGET		"target"
#define TOTEM_OPTION_HIDDEN		"hidden"
#define TOTEM_OPTION_MIMETYPE		"mimetype"
#define TOTEM_OPTION_PLAYLIST		"playlist"
#define TOTEM_OPTION_REPEAT		"repeat"
#define TOTEM_OPTION_NOAUTOSTART	"noautostart"
